package de.intevation.mxd.reader;

import java.lang.Exception;

import org.w3c.dom.Element;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.SimpleMarkerSymbol;
import com.esri.arcgis.display.ArrowMarkerSymbol;
import com.esri.arcgis.display.CharacterMarkerSymbol;
import com.esri.arcgis.display.PictureMarkerSymbol;
import com.esri.arcgis.display.MultiLayerMarkerSymbol;

/**
 * Wrapper for marker symbol reader.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleFillSymbolReader.class);

    private ISymbol symbol;

    public MarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor(ISymbol)");
        this.symbol = symbol;
    }

    public MarkerSymbolReader() {
        logger.debug("contructor()");
        this.symbol = null;
    }

    public Element read() throws Exception {
        if(symbol == null) {
            return parent;
        }

        ISymbolReader sreader = null;
        if(symbol instanceof SimpleMarkerSymbol) {
            sreader = new SimpleMarkerSymbolReader(symbol);
        }
        else if(symbol instanceof ArrowMarkerSymbol) {
            sreader = new ArrowMarkerSymbolReader(symbol);
        }
        else if(symbol instanceof CharacterMarkerSymbol) {
            sreader = new CharacterMarkerSymbolReader(symbol);
        }
        else if(symbol instanceof PictureMarkerSymbol) {
            sreader = new PictureMarkerSymbolReader(symbol);
        }
        else if(symbol instanceof MultiLayerMarkerSymbol) {
            sreader = new MultiLayerMarkerSymbolReader(symbol);
        }
        else {
            logger.debug("The reader for type " + symbol.getClass().toString() +
                         " is not implemented!");
            return parent;
        }
        if (sreader != null) {
            sreader.setParent(parent);
            sreader.setUtil(util);
            return sreader.read();
        }
        return parent;
    }

    public void setSymbol(ISymbol sym) {
        this.symbol = sym;
    }

    public boolean canRead(ISymbol sym) {
        if(sym instanceof SimpleMarkerSymbol ||
           sym instanceof ArrowMarkerSymbol ||
           sym instanceof PictureMarkerSymbol ||
           sym instanceof CharacterMarkerSymbol ||
           sym instanceof MultiLayerMarkerSymbol) {
            return true;
        }
        else {
            return false;
        }
    }

}
